@@ -22,6 +22,25 @@ def asyncWithMoreArgs(a, b, extra=None):
 uri = input("enter async server object uri: ").strip()
 proxy = Pyro4.Proxy(uri)
 
+print("\n* async call with error:")
+async = Pyro4.async(proxy)
+def resulthandler(result):
+    print("RESULT: ", result)
+def errorhandler(error):
+    print("ERRORHANDLER: ", error)
+asyncresult = async.divide(100, 0).iferror(errorhandler).then(resulthandler)
+time.sleep(4)
+print("^^^^ above an error message should be printed out...")
+print("\n* async call with error, but without errorhandler:")
+asyncresult = async.divide(100, 0).then(resulthandler)
+time.sleep(4)
+print("^^^^ above, no error message should be printed out...")
+try:
+    _ = asyncresult.value
+    print("SHOULD RAISE ERROR INSTEAD!!")
+except ZeroDivisionError as x:
+    print("expected error occurred when trying to obtain the result:", x)
+
 print("\n* async call with call chain:")
 async = Pyro4.async(proxy)
 asyncresult = async.divide(100, 5)
